@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use UI::Various::core;
 use UI::Various::Window;
@@ -87,9 +87,9 @@ sub _prepare($@)
     {
 	# Note that width/height attributes apparently are ignored, so we
 	# must use the non-attribute Wm method "geometry":
-	$self->_tk->geometry($self->{width} * $self->parent->{_char_width} .
-			     'x' .
-			     $self->{height} * $self->parent->{_char_height});
+	$self->_tk->geometry
+	    (int($self->{width}  * $self->parent->{_char_width}) . 'x' .
+	     int($self->{height} * $self->parent->{_char_height}));
     }
 
     my ($errors, $row) = (0, 0);
